@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from simple_http_server import Redirect
+from simple_http_server import ModelDict, Redirect
 from simple_http_server import Headers
 from simple_http_server import StaticFile
 from simple_http_server import HttpError
@@ -190,11 +190,10 @@ def my_ctrl4(user_name,
 def return_int(status_code=200):
     return status_code
 
-
 @request_map("/a/{pval}/{path_val}/x")
-def my_path_val_ctr(val=PathValue("pval"), path_val=PathValue()):
-    __logger.info("val is %s , path_val is %s" % (val, path_val))
-    return "<html><body>%s, %s</body></html>" % (val, path_val)
+def my_path_val_ctr(pval: PathValue, path_val=PathValue()):
+    __logger.info("val is %s , path_val is %s" % (pval, path_val))
+    return "<html><body>%s, %s</body></html>" % (pval, path_val)
 
 
 class MyController:
@@ -202,8 +201,8 @@ class MyController:
     def __init__(self) -> None:
         self._name = "ctr object"
 
-    def my_ctrl_mth(self, name: str):
-        return {"message": f"hello, {name}, {self._name} says. "}
+    def my_ctrl_mth(self, model: ModelDict):
+        return {"message": f"hello, {model['name']}, {self._name} says. "}
 
 
 my_ctrl_obj = MyController()
