@@ -39,7 +39,7 @@ from urllib.parse import unquote
 from urllib.parse import quote
 from typing import Dict, Tuple
 
-from simple_http_server import _get_session_factory
+from simple_http_server import ModelDict, _get_session_factory
 from simple_http_server import HttpError
 from simple_http_server import StaticFile
 from simple_http_server import Headers
@@ -221,14 +221,14 @@ class FilterContex:
         args = _get_args_(self.__controller)
         arg_vals = []
         for arg, arg_type_anno in args:
-            if arg not in self.request.parameter.keys() and arg_type_anno not in (Request, Session, Response, Headers, cookies.BaseCookie, cookies.SimpleCookie, Cookies):
-                raise HttpError(400, "Parameter[%s] is required]" % arg)
+            if arg not in self.request.parameter.keys() and arg_type_anno not in (Request, Session, Response, Headers, cookies.BaseCookie, cookies.SimpleCookie, Cookies, PathValue, JSONBody, ModelDict):
+                raise HttpError(400, f"Parameter[{arg}] is required! ")
             param = self.__get_params_(arg, arg_type_anno)
             arg_vals.append(param)
         return arg_vals
 
     def __get_params_(self, arg, arg_type, val=None, type_check=True):
-        if val:
+        if val is not None:
             kws = {"val": val}
         else:
             kws = {}
@@ -267,6 +267,8 @@ class FilterContex:
             param = self.__build_float(arg, **kws)
         elif arg_type == list:
             param = self.__build_list(arg, **kws)
+        elif arg_type == ModelDict:
+            param = self.__build_model_dict()
         elif arg_type == dict:
             param = self.__build_dict(arg, **kws)
         elif type_check:
@@ -275,6 +277,15 @@ class FilterContex:
             param = val
         return param
 
+    def __build_model_dict(self):
+        mdict = ModelDict()
+        for k, v in self.request.parameters.items():
+            if len(v) == 1:
+                mdict[k] = v[0]
+            else:
+                mdict[k] = v
+        return mdict
+
     def __prepare_kwargs(self):
         kwargs = _get_kwargs_(self.__controller)
         if kwargs is None:
@@ -775,13 +786,13 @@ class _HttpServerWrapper(http.server.HTTPServer, object):
 
     def __get_path_reg_pattern(self, url):
         _url = url
-        path_names = re.findall(r"(?u)\\{\\w+\\}", _url)
+        path_names = re.findall("(?u)\\{\\w+\\}", _url)
         if len(path_names) == 0:
             # normal url
             return None, path_names
         for name in path_names:
-            _url = _url.replace(name, r"([\\w%.-@!\\(\\)\\[\\]\\|\\$]+)")
-        _url = "^%s$" % _url
+            _url = _url.replace(name, "([\\w%.-@!\\(\\)\\[\\]\\|\\$]+)")
+        _url = f"^{_url}$"
 
         quoted_names = []
         for name in path_names:
